import { ViewPlugin, Decoration, EditorView } from '@codemirror/view';
// Example extension that highlights words matching a pattern
const highlightPattern = /TODO|FIXME|XXX/g;
// Create a view plugin that manages the decorations
const highlightPlugin = ViewPlugin.fromClass(class {
    constructor(view) {
        Object.defineProperty(this, "decorations", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.decorations = this.buildDecorations(view);
    }
    update(update) {
        if (update.docChanged || update.viewportChanged) {
            this.decorations = this.buildDecorations(update.view);
        }
    }
    buildDecorations(view) {
        const decorations = [];
        for (const { from, to } of view.visibleRanges) {
            const text = view.state.doc.sliceString(from, to);
            let match;
            while ((match = highlightPattern.exec(text))) {
                const start = from + match.index;
                const end = start + match[0].length;
                decorations.push(Decoration.mark({
                    class: 'cm-highlight'
                }).range(start, end));
            }
        }
        return Decoration.set(decorations);
    }
}, {
    decorations: v => v.decorations
});
// Export the extension
export const highlightExtension = [
    highlightPlugin,
    EditorView.baseTheme({
        '.cm-highlight': {
            backgroundColor: '#ffa',
            color: '#a50'
        }
    })
];
//# sourceMappingURL=basic-highlighter.js.map